@@ -2,9 +2,9 @@
 {-# LANGUAGE PatternSynonyms #-}
 {-|
 Module      : Lua
-Copyright   : © 2021-2022 Albert Krewinkel
+Copyright   : © 2021-2024 Albert Krewinkel
 License     : MIT
-Maintainer  : Albert Krewinkel <tarleb+hslua@zeitkraut.de>
+Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 Stability   : beta
 Portability : portable
 
@@ -225,6 +225,10 @@ module Lua
   , fromReference
   , toReference
 
+    -- * Debug interface
+  , lua_getupvalue
+  , lua_setupvalue
+
     -- * Ersatz functions
   , hsluaL_newstate
   , hsluaL_tolstring
@@ -241,6 +245,8 @@ module Lua
   , hslua_concat
   , hslua_arith
   , hslua_compare
+    -- ** Simplified warnings handling
+  , hsluaL_setwarnf
 
     -- * Standard Lua libraries
   , luaopen_base
@@ -254,17 +260,24 @@ module Lua
 
     -- * Push Haskell functions
   , hslua_pushhsfunction
+
+    -- * Version and copyright info
+  , pattern LUA_VERSION
+  , pattern LUA_RELEASE
+  , pattern LUA_COPYRIGHT
   ) where
 
 import Foreign.C (CInt)
 import Lua.Auxiliary
 import Lua.Call
 import Lua.Constants
+import Lua.Debug
 import Lua.Ersatz.Functions
 import Lua.Ersatz.Auxiliary
 import Lua.Lib
 import Lua.Primary
 import Lua.Types as Lua
+import Lua.Warn
 
 -- | Runs operations on a new Lua @'Lua.State'@. The state is created
 -- when the function is called and closed on return. The state, and all
